==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/HorizontalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let HorizontalAnchoredCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HorizontalAnchoredCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HorizontalAnchoredCategorySeriesDescriptionMetadata.a == null) {
                HorizontalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HorizontalAnchoredCategorySeriesDescriptionMetadata.c(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
            }
            if (a.j(HorizontalAnchoredCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.b(a);
            a.z("HorizontalAnchoredCategorySeries", HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
        }
    }
    HorizontalAnchoredCategorySeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(HorizontalAnchoredCategorySeriesDescriptionMetadata, 'HorizontalAnchoredCategorySeriesDescriptionMetadata');
    HorizontalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return HorizontalAnchoredCategorySeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/HorizontalAnchoredCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredCategorySeriesDescriptionMetadata } from "./AnchoredCategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let HorizontalAnchoredCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class HorizontalAnchoredCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (HorizontalAnchoredCategorySeriesDescriptionMetadata.a == null) {
                HorizontalAnchoredCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HorizontalAnchoredCategorySeriesDescriptionMetadata.c(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(HorizontalAnchoredCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("XAxisRef", "(w:XAxis,wf:XAxis)DataRef::object");
            a.item("XAxisRef@nameBinding", "true");
            a.item("YAxisRef", "(w:YAxis,wf:YAxis)DataRef::object");
            a.item("YAxisRef@nameBinding", "true");
        }
        static d(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.b(a);
            a.ab("HorizontalAnchoredCategorySeries", HorizontalAnchoredCategorySeriesDescriptionMetadata.a);
        }
    }
    HorizontalAnchoredCategorySeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(HorizontalAnchoredCategorySeriesDescriptionMetadata, 'HorizontalAnchoredCategorySeriesDescriptionMetadata');
    HorizontalAnchoredCategorySeriesDescriptionMetadata.a = null;
    return HorizontalAnchoredCategorySeriesDescriptionMetadata;
})();
